Add GFX908 specific changes to HIP (#1229)
* Add GFX908 specific for HIP
* Fix missing __halfTest in hipTestNativeHalf
[ROCm/clr commit: 8c82f9db77]
This commit is contained in:
committed by
Maneesh Gupta
parent
a1e4200ee8
commit
73af1ac4bd
@@ -29,7 +29,7 @@ THE SOFTWARE.
|
||||
#include "hip/hip_runtime.h"
|
||||
#include "test_common.h"
|
||||
|
||||
#if __HIP_ARCH_GFX803__ || __HIP_ARCH_GFX900__ || __HIP_ARCH_GFX906__
|
||||
#if __HIP_ARCH_GFX803__ || __HIP_ARCH_GFX900__ || __HIP_ARCH_GFX906__ || __HIP_ARCH_GFX908__
|
||||
|
||||
__global__ void kernel_abs_int64(long long *input, long long *output) {
|
||||
int tx = threadIdx.x;
|
||||
|
||||
Reference in New Issue
Block a user